@@ -25,6 +25,7 @@ DEFAULT_CONFIG = {
         'show_text_sz': 40,
         'show_text': "name location",
         'text_justify': 'L',
+        'text_bkg_hgt': 0.25,
         'fit': False,
         #'auto_resize': True,
         'kenburns': False,
@@ -48,6 +49,8 @@ DEFAULT_CONFIG = {
         'clock_text_sz': 120,
         'clock_format': "%I:%M",
         #'codepoints': "1234567890AÄÀÆÅÃBCÇDÈÉÊEËFGHIÏÍJKLMNÑOÓÖÔŌØPQRSTUÚÙÜVWXYZaáàãæåäbcçdeéèêëfghiíïjklmnñoóôōøöpqrsßtuúüvwxyz., _-+*()&/`´'•" # limit to 121 ie 11x11 grid_size
+        'menu_text_sz': 40,
+        'menu_autohide_tm': 10.0,
     },
     'model': {
 
@@ -71,7 +74,6 @@ DEFAULT_CONFIG = {
         'deleted_pictures': '~/DeletedPictures',
         'log_level': 'WARNING',
         'log_file': '',
-        'use_kbd': False,
     },
     'mqtt': {
         'use_mqtt': False,                          # Set tue true, to enable mqtt
@@ -81,6 +83,7 @@ DEFAULT_CONFIG = {
         'password': '',
         'tls': '',
         'device_id': 'picframe',                                 # unique id of device. change if there is more than one picture frame
+        'device_url': '',
     },
     'http': {
         'use_http': False,
@@ -89,7 +92,17 @@ DEFAULT_CONFIG = {
         'use_ssl': False,
         'keyfile': "/path/to/key.pem",
         'certfile': "/path/to/fullchain.pem"
-    }
+    },
+    'peripherals': {
+        'input_type': None,                                      # valid options: {None, "keyboard", "touch", "mouse"}
+        'buttons': {
+            'pause': {'enable': True, 'label': 'Pause', 'shortcut': ' '},
+            'display_off': {'enable': True, 'label': 'Display off', 'shortcut': 'o'},
+            'location': {'enable': False, 'label': 'Location', 'shortcut': 'l'},
+            'exit': {'enable': False, 'label': 'Exit', 'shortcut': 'e'},
+            'power_down': {'enable': False, 'label': 'Power down', 'shortcut': 'p'}
+        },
+    },
 }
 
 
@@ -136,7 +149,7 @@ class Model:
         with open(configfile, 'r') as stream:
             try:
                 conf = yaml.safe_load(stream)
-                for section in ['viewer', 'model', 'mqtt', 'http']:
+                for section in ['viewer', 'model', 'mqtt', 'http', 'peripherals']:
                     self.__config[section] = {**DEFAULT_CONFIG[section], **conf[section]}
 
                 self.__logger.debug('config data = %s', self.__config)
@@ -193,6 +206,9 @@ class Model:
     def get_http_config(self):
         return self.__config['http']
 
+    def get_peripherals_config(self):
+        return self.__config['peripherals']
+
     @property
     def fade_time(self):
         return self.__config['model']['fade_time']
